@@ -815,7 +815,7 @@ config_str yon_config_get_load_parameters_by_list(int *size, config_str paramete
 
 config_str yon_config_get_save_parameters_by_list(int *size, config_str parameters, int params_size);
 
-config_str yon_config_get_save_parameters_by_key(int *size, char *parameter,...);
+config_str yon_config_get_save_parameters_by_key(int *size, ...);
 
 config_str yon_config_get_save_parameters(int *size);
 
@@ -863,6 +863,8 @@ int yon_config_parse_parameter(char *parameter,char **key, char **value);
 
 int yon_char_remove_brackets(char *string);
 
+char *yon_char_get_element(char *target, unsigned int position, char *divider);
+
 int yon_config_command_get_section_pos(const char *);
 char *yon_config_command_get_section(const char *command);
 
@@ -1053,6 +1055,8 @@ char *yon_config_save_simple(YON_CONFIG_TYPE target, char *path);
 [[ deprecated ( "Will be removed soon" ) ]]
 int yon_config_force_save_registered(char *path);
 
+config_str yon_config_find_keys(char *target, int *size);
+
 /**yon_config_get_all(int *size)
  * [EN]
  * 
@@ -1094,4 +1098,36 @@ void yon_launch(char *command);
 
 // void *yon_malloc(int size, char *group_key);
 
+#define LOCALES_DOMAIN_NAME "libublsettings"
+
+enum YON_LOCALE_PARAMETER{
+    YON_LOCALE_LANGUAGE,
+    YON_LOCALE_LANG_NAME,
+    YON_LOCALE_TERRITORY,
+    YON_LOCALE_LANG_AB,
+    YON_LOCALE_TITLE
+};
+
+typedef struct yon_hash_element{
+    dictionary_fields(yon_hash_element);
+} yon_hash_element;
+
+typedef struct {
+    yon_hash_element **data;
+    unsigned int size;
+    unsigned int(*hash_func)(const char *);
+} yon_hash;
+
+unsigned int yon_str_hash(const char *str);
+
+yon_hash *yon_hash_new(int size, unsigned int(*hash_func)(const char *));
+int yon_hash_insert(yon_hash *target, const char *key, void *data);
+int yon_hash_remove(yon_hash *target, const char *key);
+void *yon_hash_lookup(yon_hash *target, const char *key);
+int yon_hash_add(yon_hash *target,const char *key);
+int yon_hash_contains(yon_hash *target, const char *key);
+void yon_locale_init();
+config_str yon_locale_get_all_codes(int *size);
+char *yon_locale_get_parameter(char *code,enum YON_LOCALE_PARAMETER type);
+
 #endif
\ No newline at end of file
